# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/plugins/sidecar.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from k8s.io.api.core.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/plugins/sidecar.proto',
  package='flyteidl.plugins',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/plugins'),
  serialized_pb=_b('\n\x1e\x66lyteidl/plugins/sidecar.proto\x12\x10\x66lyteidl.plugins\x1a\"k8s.io/api/core/v1/generated.proto\"\xbc\x02\n\nSidecarJob\x12-\n\x08pod_spec\x18\x01 \x01(\x0b\x32\x1b.k8s.io.api.core.v1.PodSpec\x12\x1e\n\x16primary_container_name\x18\x02 \x01(\t\x12\x42\n\x0b\x61nnotations\x18\x03 \x03(\x0b\x32-.flyteidl.plugins.SidecarJob.AnnotationsEntry\x12\x38\n\x06labels\x18\x04 \x03(\x0b\x32(.flyteidl.plugins.SidecarJob.LabelsEntry\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x39Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/pluginsb\x06proto3')
  ,
  dependencies=[k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2.DESCRIPTOR,])




_SIDECARJOB_ANNOTATIONSENTRY = _descriptor.Descriptor(
  name='AnnotationsEntry',
  full_name='flyteidl.plugins.SidecarJob.AnnotationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='flyteidl.plugins.SidecarJob.AnnotationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='flyteidl.plugins.SidecarJob.AnnotationsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=308,
  serialized_end=358,
)

_SIDECARJOB_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='flyteidl.plugins.SidecarJob.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='flyteidl.plugins.SidecarJob.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='flyteidl.plugins.SidecarJob.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=360,
  serialized_end=405,
)

_SIDECARJOB = _descriptor.Descriptor(
  name='SidecarJob',
  full_name='flyteidl.plugins.SidecarJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pod_spec', full_name='flyteidl.plugins.SidecarJob.pod_spec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='primary_container_name', full_name='flyteidl.plugins.SidecarJob.primary_container_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='flyteidl.plugins.SidecarJob.annotations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='flyteidl.plugins.SidecarJob.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SIDECARJOB_ANNOTATIONSENTRY, _SIDECARJOB_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=405,
)

_SIDECARJOB_ANNOTATIONSENTRY.containing_type = _SIDECARJOB
_SIDECARJOB_LABELSENTRY.containing_type = _SIDECARJOB
_SIDECARJOB.fields_by_name['pod_spec'].message_type = k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2._PODSPEC
_SIDECARJOB.fields_by_name['annotations'].message_type = _SIDECARJOB_ANNOTATIONSENTRY
_SIDECARJOB.fields_by_name['labels'].message_type = _SIDECARJOB_LABELSENTRY
DESCRIPTOR.message_types_by_name['SidecarJob'] = _SIDECARJOB
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SidecarJob = _reflection.GeneratedProtocolMessageType('SidecarJob', (_message.Message,), dict(

  AnnotationsEntry = _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), dict(
    DESCRIPTOR = _SIDECARJOB_ANNOTATIONSENTRY,
    __module__ = 'flyteidl.plugins.sidecar_pb2'
    # @@protoc_insertion_point(class_scope:flyteidl.plugins.SidecarJob.AnnotationsEntry)
    ))
  ,

  LabelsEntry = _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), dict(
    DESCRIPTOR = _SIDECARJOB_LABELSENTRY,
    __module__ = 'flyteidl.plugins.sidecar_pb2'
    # @@protoc_insertion_point(class_scope:flyteidl.plugins.SidecarJob.LabelsEntry)
    ))
  ,
  DESCRIPTOR = _SIDECARJOB,
  __module__ = 'flyteidl.plugins.sidecar_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.SidecarJob)
  ))
_sym_db.RegisterMessage(SidecarJob)
_sym_db.RegisterMessage(SidecarJob.AnnotationsEntry)
_sym_db.RegisterMessage(SidecarJob.LabelsEntry)


DESCRIPTOR._options = None
_SIDECARJOB_ANNOTATIONSENTRY._options = None
_SIDECARJOB_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/project.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.admin import common_pb2 as flyteidl_dot_admin_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/admin/project.proto',
  package='flyteidl.admin',
  syntax='proto3',
  serialized_options=_b('Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin'),
  serialized_pb=_b('\n\x1c\x66lyteidl/admin/project.proto\x12\x0e\x66lyteidl.admin\x1a\x1b\x66lyteidl/admin/common.proto\"\"\n\x06\x44omain\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xfe\x01\n\x07Project\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\'\n\x07\x64omains\x18\x03 \x03(\x0b\x32\x16.flyteidl.admin.Domain\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12&\n\x06labels\x18\x05 \x01(\x0b\x32\x16.flyteidl.admin.Labels\x12\x33\n\x05state\x18\x06 \x01(\x0e\x32$.flyteidl.admin.Project.ProjectState\">\n\x0cProjectState\x12\n\n\x06\x41\x43TIVE\x10\x00\x12\x0c\n\x08\x41RCHIVED\x10\x01\x12\x14\n\x10SYSTEM_GENERATED\x10\x02\"D\n\x08Projects\x12)\n\x08projects\x18\x01 \x03(\x0b\x32\x17.flyteidl.admin.Project\x12\r\n\x05token\x18\x02 \x01(\t\"j\n\x12ProjectListRequest\x12\r\n\x05limit\x18\x01 \x01(\r\x12\r\n\x05token\x18\x02 \x01(\t\x12\x0f\n\x07\x66ilters\x18\x03 \x01(\t\x12%\n\x07sort_by\x18\x04 \x01(\x0b\x32\x14.flyteidl.admin.Sort\"B\n\x16ProjectRegisterRequest\x12(\n\x07project\x18\x01 \x01(\x0b\x32\x17.flyteidl.admin.Project\"\x19\n\x17ProjectRegisterResponse\"\x17\n\x15ProjectUpdateResponseB7Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/adminb\x06proto3')
  ,
  dependencies=[flyteidl_dot_admin_dot_common__pb2.DESCRIPTOR,])



_PROJECT_PROJECTSTATE = _descriptor.EnumDescriptor(
  name='ProjectState',
  full_name='flyteidl.admin.Project.ProjectState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ARCHIVED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYSTEM_GENERATED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=306,
  serialized_end=368,
)
_sym_db.RegisterEnumDescriptor(_PROJECT_PROJECTSTATE)


_DOMAIN = _descriptor.Descriptor(
  name='Domain',
  full_name='flyteidl.admin.Domain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.Domain.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='flyteidl.admin.Domain.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=111,
)


_PROJECT = _descriptor.Descriptor(
  name='Project',
  full_name='flyteidl.admin.Project',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.Project.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='flyteidl.admin.Project.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domains', full_name='flyteidl.admin.Project.domains', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='flyteidl.admin.Project.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='flyteidl.admin.Project.labels', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='flyteidl.admin.Project.state', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROJECT_PROJECTSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=368,
)


_PROJECTS = _descriptor.Descriptor(
  name='Projects',
  full_name='flyteidl.admin.Projects',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='projects', full_name='flyteidl.admin.Projects.projects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='flyteidl.admin.Projects.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=370,
  serialized_end=438,
)


_PROJECTLISTREQUEST = _descriptor.Descriptor(
  name='ProjectListRequest',
  full_name='flyteidl.admin.ProjectListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='limit', full_name='flyteidl.admin.ProjectListRequest.limit', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='flyteidl.admin.ProjectListRequest.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filters', full_name='flyteidl.admin.ProjectListRequest.filters', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_by', full_name='flyteidl.admin.ProjectListRequest.sort_by', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=546,
)


_PROJECTREGISTERREQUEST = _descriptor.Descriptor(
  name='ProjectRegisterRequest',
  full_name='flyteidl.admin.ProjectRegisterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='flyteidl.admin.ProjectRegisterRequest.project', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=548,
  serialized_end=614,
)


_PROJECTREGISTERRESPONSE = _descriptor.Descriptor(
  name='ProjectRegisterResponse',
  full_name='flyteidl.admin.ProjectRegisterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=641,
)


_PROJECTUPDATERESPONSE = _descriptor.Descriptor(
  name='ProjectUpdateResponse',
  full_name='flyteidl.admin.ProjectUpdateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=643,
  serialized_end=666,
)

_PROJECT.fields_by_name['domains'].message_type = _DOMAIN
_PROJECT.fields_by_name['labels'].message_type = flyteidl_dot_admin_dot_common__pb2._LABELS
_PROJECT.fields_by_name['state'].enum_type = _PROJECT_PROJECTSTATE
_PROJECT_PROJECTSTATE.containing_type = _PROJECT
_PROJECTS.fields_by_name['projects'].message_type = _PROJECT
_PROJECTLISTREQUEST.fields_by_name['sort_by'].message_type = flyteidl_dot_admin_dot_common__pb2._SORT
_PROJECTREGISTERREQUEST.fields_by_name['project'].message_type = _PROJECT
DESCRIPTOR.message_types_by_name['Domain'] = _DOMAIN
DESCRIPTOR.message_types_by_name['Project'] = _PROJECT
DESCRIPTOR.message_types_by_name['Projects'] = _PROJECTS
DESCRIPTOR.message_types_by_name['ProjectListRequest'] = _PROJECTLISTREQUEST
DESCRIPTOR.message_types_by_name['ProjectRegisterRequest'] = _PROJECTREGISTERREQUEST
DESCRIPTOR.message_types_by_name['ProjectRegisterResponse'] = _PROJECTREGISTERRESPONSE
DESCRIPTOR.message_types_by_name['ProjectUpdateResponse'] = _PROJECTUPDATERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Domain = _reflection.GeneratedProtocolMessageType('Domain', (_message.Message,), dict(
  DESCRIPTOR = _DOMAIN,
  __module__ = 'flyteidl.admin.project_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Domain)
  ))
_sym_db.RegisterMessage(Domain)

Project = _reflection.GeneratedProtocolMessageType('Project', (_message.Message,), dict(
  DESCRIPTOR = _PROJECT,
  __module__ = 'flyteidl.admin.project_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Project)
  ))
_sym_db.RegisterMessage(Project)

Projects = _reflection.GeneratedProtocolMessageType('Projects', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTS,
  __module__ = 'flyteidl.admin.project_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Projects)
  ))
_sym_db.RegisterMessage(Projects)

ProjectListRequest = _reflection.GeneratedProtocolMessageType('ProjectListRequest', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTLISTREQUEST,
  __module__ = 'flyteidl.admin.project_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectListRequest)
  ))
_sym_db.RegisterMessage(ProjectListRequest)

ProjectRegisterRequest = _reflection.GeneratedProtocolMessageType('ProjectRegisterRequest', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTREGISTERREQUEST,
  __module__ = 'flyteidl.admin.project_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectRegisterRequest)
  ))
_sym_db.RegisterMessage(ProjectRegisterRequest)

ProjectRegisterResponse = _reflection.GeneratedProtocolMessageType('ProjectRegisterResponse', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTREGISTERRESPONSE,
  __module__ = 'flyteidl.admin.project_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectRegisterResponse)
  ))
_sym_db.RegisterMessage(ProjectRegisterResponse)

ProjectUpdateResponse = _reflection.GeneratedProtocolMessageType('ProjectUpdateResponse', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTUPDATERESPONSE,
  __module__ = 'flyteidl.admin.project_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectUpdateResponse)
  ))
_sym_db.RegisterMessage(ProjectUpdateResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from flyteidl.datacatalog import datacatalog_pb2 as flyteidl_dot_datacatalog_dot_datacatalog__pb2


class DataCatalogStub(object):
  """
  Data Catalog service definition
  Data Catalog is a service for indexing parameterized, strongly-typed data artifacts across revisions.
  Artifacts are associated with a Dataset, and can be tagged for retrieval.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateDataset = channel.unary_unary(
        '/datacatalog.DataCatalog/CreateDataset',
        request_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.CreateDatasetRequest.SerializeToString,
        response_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.CreateDatasetResponse.FromString,
        )
    self.GetDataset = channel.unary_unary(
        '/datacatalog.DataCatalog/GetDataset',
        request_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GetDatasetRequest.SerializeToString,
        response_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GetDatasetResponse.FromString,
        )
    self.CreateArtifact = channel.unary_unary(
        '/datacatalog.DataCatalog/CreateArtifact',
        request_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.CreateArtifactRequest.SerializeToString,
        response_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.CreateArtifactResponse.FromString,
        )
    self.GetArtifact = channel.unary_unary(
        '/datacatalog.DataCatalog/GetArtifact',
        request_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GetArtifactRequest.SerializeToString,
        response_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GetArtifactResponse.FromString,
        )
    self.AddTag = channel.unary_unary(
        '/datacatalog.DataCatalog/AddTag',
        request_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.AddTagRequest.SerializeToString,
        response_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.AddTagResponse.FromString,
        )
    self.ListArtifacts = channel.unary_unary(
        '/datacatalog.DataCatalog/ListArtifacts',
        request_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.ListArtifactsRequest.SerializeToString,
        response_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.ListArtifactsResponse.FromString,
        )
    self.ListDatasets = channel.unary_unary(
        '/datacatalog.DataCatalog/ListDatasets',
        request_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.ListDatasetsRequest.SerializeToString,
        response_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.ListDatasetsResponse.FromString,
        )
    self.GetOrReserveArtifact = channel.unary_unary(
        '/datacatalog.DataCatalog/GetOrReserveArtifact',
        request_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GetOrReserveArtifactRequest.SerializeToString,
        response_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GetOrReserveArtifactResponse.FromString,
        )
    self.ExtendReservation = channel.unary_unary(
        '/datacatalog.DataCatalog/ExtendReservation',
        request_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.ExtendReservationRequest.SerializeToString,
        response_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.ExtendReservationResponse.FromString,
        )
    self.ReleaseReservation = channel.unary_unary(
        '/datacatalog.DataCatalog/ReleaseReservation',
        request_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.ReleaseReservationRequest.SerializeToString,
        response_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.ReleaseReservationResponse.FromString,
        )


class DataCatalogServicer(object):
  """
  Data Catalog service definition
  Data Catalog is a service for indexing parameterized, strongly-typed data artifacts across revisions.
  Artifacts are associated with a Dataset, and can be tagged for retrieval.
  """

  def CreateDataset(self, request, context):
    """Create a new Dataset. Datasets are unique based on the DatasetID. Datasets are logical groupings of artifacts.
    Each dataset can have one or more artifacts
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetDataset(self, request, context):
    """Get a Dataset by the DatasetID. This returns the Dataset with the associated metadata.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateArtifact(self, request, context):
    """Create an artifact and the artifact data associated with it. An artifact can be a hive partition or arbitrary
    files or data values
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetArtifact(self, request, context):
    """Retrieve an artifact by an identifying handle. This returns an artifact along with the artifact data.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddTag(self, request, context):
    """Associate a tag with an artifact. Tags are unique within a Dataset.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListArtifacts(self, request, context):
    """Return a paginated list of artifacts
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListDatasets(self, request, context):
    """Return a paginated list of datasets
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetOrReserveArtifact(self, request, context):
    """Get an artifact and the corresponding data. If the artifact does not exist,
    try to reserve a spot for populating the artifact.
    Once you preserve a spot, you should call ExtendReservation API periodically
    to extend the reservation. Otherwise, the reservation can expire and other
    tasks may take the spot.
    If the same owner_id calls this API for the same dataset and it has an active reservation and the artifacts have not been written yet by a different owner, the API will respond with an Acquired Reservation Status (providing idempotency).
    Note: We may have multiple concurrent tasks with the same signature
    and the same input that try to populate the same artifact at the same time.
    Thus with reservation, only one task can run at a time, until the reservation
    expires.
    Note: If task A does not extend the reservation in time and the reservation
    expires, another task B may take over the reservation, resulting in two tasks
    A and B running in parallel. So a third task C may get the Artifact from A or B,
    whichever writes last.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ExtendReservation(self, request, context):
    """Extend the reservation to keep it from expiring. If the reservation expires,
    other tasks can take over the reservation by calling GetOrReserveArtifact.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ReleaseReservation(self, request, context):
    """Release the reservation when the task holding the spot fails so that the other tasks
    can grab the spot.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DataCatalogServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateDataset': grpc.unary_unary_rpc_method_handler(
          servicer.CreateDataset,
          request_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.CreateDatasetRequest.FromString,
          response_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.CreateDatasetResponse.SerializeToString,
      ),
      'GetDataset': grpc.unary_unary_rpc_method_handler(
          servicer.GetDataset,
          request_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GetDatasetRequest.FromString,
          response_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GetDatasetResponse.SerializeToString,
      ),
      'CreateArtifact': grpc.unary_unary_rpc_method_handler(
          servicer.CreateArtifact,
          request_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.CreateArtifactRequest.FromString,
          response_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.CreateArtifactResponse.SerializeToString,
      ),
      'GetArtifact': grpc.unary_unary_rpc_method_handler(
          servicer.GetArtifact,
          request_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GetArtifactRequest.FromString,
          response_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GetArtifactResponse.SerializeToString,
      ),
      'AddTag': grpc.unary_unary_rpc_method_handler(
          servicer.AddTag,
          request_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.AddTagRequest.FromString,
          response_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.AddTagResponse.SerializeToString,
      ),
      'ListArtifacts': grpc.unary_unary_rpc_method_handler(
          servicer.ListArtifacts,
          request_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.ListArtifactsRequest.FromString,
          response_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.ListArtifactsResponse.SerializeToString,
      ),
      'ListDatasets': grpc.unary_unary_rpc_method_handler(
          servicer.ListDatasets,
          request_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.ListDatasetsRequest.FromString,
          response_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.ListDatasetsResponse.SerializeToString,
      ),
      'GetOrReserveArtifact': grpc.unary_unary_rpc_method_handler(
          servicer.GetOrReserveArtifact,
          request_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GetOrReserveArtifactRequest.FromString,
          response_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.GetOrReserveArtifactResponse.SerializeToString,
      ),
      'ExtendReservation': grpc.unary_unary_rpc_method_handler(
          servicer.ExtendReservation,
          request_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.ExtendReservationRequest.FromString,
          response_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.ExtendReservationResponse.SerializeToString,
      ),
      'ReleaseReservation': grpc.unary_unary_rpc_method_handler(
          servicer.ReleaseReservation,
          request_deserializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.ReleaseReservationRequest.FromString,
          response_serializer=flyteidl_dot_datacatalog_dot_datacatalog__pb2.ReleaseReservationResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'datacatalog.DataCatalog', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/workflow_attributes.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.admin import matchable_resource_pb2 as flyteidl_dot_admin_dot_matchable__resource__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/admin/workflow_attributes.proto',
  package='flyteidl.admin',
  syntax='proto3',
  serialized_options=_b('Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin'),
  serialized_pb=_b('\n(flyteidl/admin/workflow_attributes.proto\x12\x0e\x66lyteidl.admin\x1a\'flyteidl/admin/matchable_resource.proto\"\x88\x01\n\x12WorkflowAttributes\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\x10\n\x08workflow\x18\x03 \x01(\t\x12?\n\x13matching_attributes\x18\x04 \x01(\x0b\x32\".flyteidl.admin.MatchingAttributes\"Y\n\x1fWorkflowAttributesUpdateRequest\x12\x36\n\nattributes\x18\x01 \x01(\x0b\x32\".flyteidl.admin.WorkflowAttributes\"\"\n WorkflowAttributesUpdateResponse\"\x8b\x01\n\x1cWorkflowAttributesGetRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\x10\n\x08workflow\x18\x03 \x01(\t\x12\x38\n\rresource_type\x18\x04 \x01(\x0e\x32!.flyteidl.admin.MatchableResource\"W\n\x1dWorkflowAttributesGetResponse\x12\x36\n\nattributes\x18\x01 \x01(\x0b\x32\".flyteidl.admin.WorkflowAttributes\"\x8e\x01\n\x1fWorkflowAttributesDeleteRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\x10\n\x08workflow\x18\x03 \x01(\t\x12\x38\n\rresource_type\x18\x04 \x01(\x0e\x32!.flyteidl.admin.MatchableResource\"\"\n WorkflowAttributesDeleteResponseB7Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/adminb\x06proto3')
  ,
  dependencies=[flyteidl_dot_admin_dot_matchable__resource__pb2.DESCRIPTOR,])




_WORKFLOWATTRIBUTES = _descriptor.Descriptor(
  name='WorkflowAttributes',
  full_name='flyteidl.admin.WorkflowAttributes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='flyteidl.admin.WorkflowAttributes.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='flyteidl.admin.WorkflowAttributes.domain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='flyteidl.admin.WorkflowAttributes.workflow', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='matching_attributes', full_name='flyteidl.admin.WorkflowAttributes.matching_attributes', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=102,
  serialized_end=238,
)


_WORKFLOWATTRIBUTESUPDATEREQUEST = _descriptor.Descriptor(
  name='WorkflowAttributesUpdateRequest',
  full_name='flyteidl.admin.WorkflowAttributesUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attributes', full_name='flyteidl.admin.WorkflowAttributesUpdateRequest.attributes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=329,
)


_WORKFLOWATTRIBUTESUPDATERESPONSE = _descriptor.Descriptor(
  name='WorkflowAttributesUpdateResponse',
  full_name='flyteidl.admin.WorkflowAttributesUpdateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=331,
  serialized_end=365,
)


_WORKFLOWATTRIBUTESGETREQUEST = _descriptor.Descriptor(
  name='WorkflowAttributesGetRequest',
  full_name='flyteidl.admin.WorkflowAttributesGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='flyteidl.admin.WorkflowAttributesGetRequest.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='flyteidl.admin.WorkflowAttributesGetRequest.domain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='flyteidl.admin.WorkflowAttributesGetRequest.workflow', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='flyteidl.admin.WorkflowAttributesGetRequest.resource_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=368,
  serialized_end=507,
)


_WORKFLOWATTRIBUTESGETRESPONSE = _descriptor.Descriptor(
  name='WorkflowAttributesGetResponse',
  full_name='flyteidl.admin.WorkflowAttributesGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attributes', full_name='flyteidl.admin.WorkflowAttributesGetResponse.attributes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=509,
  serialized_end=596,
)


_WORKFLOWATTRIBUTESDELETEREQUEST = _descriptor.Descriptor(
  name='WorkflowAttributesDeleteRequest',
  full_name='flyteidl.admin.WorkflowAttributesDeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='flyteidl.admin.WorkflowAttributesDeleteRequest.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='flyteidl.admin.WorkflowAttributesDeleteRequest.domain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='flyteidl.admin.WorkflowAttributesDeleteRequest.workflow', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='flyteidl.admin.WorkflowAttributesDeleteRequest.resource_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=599,
  serialized_end=741,
)


_WORKFLOWATTRIBUTESDELETERESPONSE = _descriptor.Descriptor(
  name='WorkflowAttributesDeleteResponse',
  full_name='flyteidl.admin.WorkflowAttributesDeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=743,
  serialized_end=777,
)

_WORKFLOWATTRIBUTES.fields_by_name['matching_attributes'].message_type = flyteidl_dot_admin_dot_matchable__resource__pb2._MATCHINGATTRIBUTES
_WORKFLOWATTRIBUTESUPDATEREQUEST.fields_by_name['attributes'].message_type = _WORKFLOWATTRIBUTES
_WORKFLOWATTRIBUTESGETREQUEST.fields_by_name['resource_type'].enum_type = flyteidl_dot_admin_dot_matchable__resource__pb2._MATCHABLERESOURCE
_WORKFLOWATTRIBUTESGETRESPONSE.fields_by_name['attributes'].message_type = _WORKFLOWATTRIBUTES
_WORKFLOWATTRIBUTESDELETEREQUEST.fields_by_name['resource_type'].enum_type = flyteidl_dot_admin_dot_matchable__resource__pb2._MATCHABLERESOURCE
DESCRIPTOR.message_types_by_name['WorkflowAttributes'] = _WORKFLOWATTRIBUTES
DESCRIPTOR.message_types_by_name['WorkflowAttributesUpdateRequest'] = _WORKFLOWATTRIBUTESUPDATEREQUEST
DESCRIPTOR.message_types_by_name['WorkflowAttributesUpdateResponse'] = _WORKFLOWATTRIBUTESUPDATERESPONSE
DESCRIPTOR.message_types_by_name['WorkflowAttributesGetRequest'] = _WORKFLOWATTRIBUTESGETREQUEST
DESCRIPTOR.message_types_by_name['WorkflowAttributesGetResponse'] = _WORKFLOWATTRIBUTESGETRESPONSE
DESCRIPTOR.message_types_by_name['WorkflowAttributesDeleteRequest'] = _WORKFLOWATTRIBUTESDELETEREQUEST
DESCRIPTOR.message_types_by_name['WorkflowAttributesDeleteResponse'] = _WORKFLOWATTRIBUTESDELETERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WorkflowAttributes = _reflection.GeneratedProtocolMessageType('WorkflowAttributes', (_message.Message,), dict(
  DESCRIPTOR = _WORKFLOWATTRIBUTES,
  __module__ = 'flyteidl.admin.workflow_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.WorkflowAttributes)
  ))
_sym_db.RegisterMessage(WorkflowAttributes)

WorkflowAttributesUpdateRequest = _reflection.GeneratedProtocolMessageType('WorkflowAttributesUpdateRequest', (_message.Message,), dict(
  DESCRIPTOR = _WORKFLOWATTRIBUTESUPDATEREQUEST,
  __module__ = 'flyteidl.admin.workflow_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.WorkflowAttributesUpdateRequest)
  ))
_sym_db.RegisterMessage(WorkflowAttributesUpdateRequest)

WorkflowAttributesUpdateResponse = _reflection.GeneratedProtocolMessageType('WorkflowAttributesUpdateResponse', (_message.Message,), dict(
  DESCRIPTOR = _WORKFLOWATTRIBUTESUPDATERESPONSE,
  __module__ = 'flyteidl.admin.workflow_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.WorkflowAttributesUpdateResponse)
  ))
_sym_db.RegisterMessage(WorkflowAttributesUpdateResponse)

WorkflowAttributesGetRequest = _reflection.GeneratedProtocolMessageType('WorkflowAttributesGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _WORKFLOWATTRIBUTESGETREQUEST,
  __module__ = 'flyteidl.admin.workflow_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.WorkflowAttributesGetRequest)
  ))
_sym_db.RegisterMessage(WorkflowAttributesGetRequest)

WorkflowAttributesGetResponse = _reflection.GeneratedProtocolMessageType('WorkflowAttributesGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _WORKFLOWATTRIBUTESGETRESPONSE,
  __module__ = 'flyteidl.admin.workflow_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.WorkflowAttributesGetResponse)
  ))
_sym_db.RegisterMessage(WorkflowAttributesGetResponse)

WorkflowAttributesDeleteRequest = _reflection.GeneratedProtocolMessageType('WorkflowAttributesDeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _WORKFLOWATTRIBUTESDELETEREQUEST,
  __module__ = 'flyteidl.admin.workflow_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.WorkflowAttributesDeleteRequest)
  ))
_sym_db.RegisterMessage(WorkflowAttributesDeleteRequest)

WorkflowAttributesDeleteResponse = _reflection.GeneratedProtocolMessageType('WorkflowAttributesDeleteResponse', (_message.Message,), dict(
  DESCRIPTOR = _WORKFLOWATTRIBUTESDELETERESPONSE,
  __module__ = 'flyteidl.admin.workflow_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.WorkflowAttributesDeleteResponse)
  ))
_sym_db.RegisterMessage(WorkflowAttributesDeleteResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from flyteidl.service import identity_pb2 as flyteidl_dot_service_dot_identity__pb2


class IdentityServiceStub(object):
  """IdentityService defines an RPC Service that interacts with user/app identities.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.UserInfo = channel.unary_unary(
        '/flyteidl.service.IdentityService/UserInfo',
        request_serializer=flyteidl_dot_service_dot_identity__pb2.UserInfoRequest.SerializeToString,
        response_deserializer=flyteidl_dot_service_dot_identity__pb2.UserInfoResponse.FromString,
        )


class IdentityServiceServicer(object):
  """IdentityService defines an RPC Service that interacts with user/app identities.
  """

  def UserInfo(self, request, context):
    """Retrieves user information about the currently logged in user.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_IdentityServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'UserInfo': grpc.unary_unary_rpc_method_handler(
          servicer.UserInfo,
          request_deserializer=flyteidl_dot_service_dot_identity__pb2.UserInfoRequest.FromString,
          response_serializer=flyteidl_dot_service_dot_identity__pb2.UserInfoResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'flyteidl.service.IdentityService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/core/types.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/core/types.proto',
  package='flyteidl.core',
  syntax='proto3',
  serialized_options=_b('Z4github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/core'),
  serialized_pb=_b('\n\x19\x66lyteidl/core/types.proto\x12\rflyteidl.core\x1a\x1cgoogle/protobuf/struct.proto\"\x8c\x02\n\nSchemaType\x12\x37\n\x07\x63olumns\x18\x03 \x03(\x0b\x32&.flyteidl.core.SchemaType.SchemaColumn\x1a\xc4\x01\n\x0cSchemaColumn\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x45\n\x04type\x18\x02 \x01(\x0e\x32\x37.flyteidl.core.SchemaType.SchemaColumn.SchemaColumnType\"_\n\x10SchemaColumnType\x12\x0b\n\x07INTEGER\x10\x00\x12\t\n\x05\x46LOAT\x10\x01\x12\n\n\x06STRING\x10\x02\x12\x0b\n\x07\x42OOLEAN\x10\x03\x12\x0c\n\x08\x44\x41TETIME\x10\x04\x12\x0c\n\x08\x44URATION\x10\x05\"\x8f\x01\n\x08\x42lobType\x12\x0e\n\x06\x66ormat\x18\x01 \x01(\t\x12\x42\n\x0e\x64imensionality\x18\x02 \x01(\x0e\x32*.flyteidl.core.BlobType.BlobDimensionality\"/\n\x12\x42lobDimensionality\x12\n\n\x06SINGLE\x10\x00\x12\r\n\tMULTIPART\x10\x01\"\x1a\n\x08\x45numType\x12\x0e\n\x06values\x18\x01 \x03(\t\"\xde\x02\n\x0bLiteralType\x12+\n\x06simple\x18\x01 \x01(\x0e\x32\x19.flyteidl.core.SimpleTypeH\x00\x12+\n\x06schema\x18\x02 \x01(\x0b\x32\x19.flyteidl.core.SchemaTypeH\x00\x12\x35\n\x0f\x63ollection_type\x18\x03 \x01(\x0b\x32\x1a.flyteidl.core.LiteralTypeH\x00\x12\x34\n\x0emap_value_type\x18\x04 \x01(\x0b\x32\x1a.flyteidl.core.LiteralTypeH\x00\x12\'\n\x04\x62lob\x18\x05 \x01(\x0b\x32\x17.flyteidl.core.BlobTypeH\x00\x12,\n\tenum_type\x18\x07 \x01(\x0b\x32\x17.flyteidl.core.EnumTypeH\x00\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructB\x06\n\x04type\"/\n\x0fOutputReference\x12\x0f\n\x07node_id\x18\x01 \x01(\t\x12\x0b\n\x03var\x18\x02 \x01(\t\"0\n\x05\x45rror\x12\x16\n\x0e\x66\x61iled_node_id\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t*\x86\x01\n\nSimpleType\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07INTEGER\x10\x01\x12\t\n\x05\x46LOAT\x10\x02\x12\n\n\x06STRING\x10\x03\x12\x0b\n\x07\x42OOLEAN\x10\x04\x12\x0c\n\x08\x44\x41TETIME\x10\x05\x12\x0c\n\x08\x44URATION\x10\x06\x12\n\n\x06\x42INARY\x10\x07\x12\t\n\x05\x45RROR\x10\x08\x12\n\n\x06STRUCT\x10\tB6Z4github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/coreb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])

_SIMPLETYPE = _descriptor.EnumDescriptor(
  name='SimpleType',
  full_name='flyteidl.core.SimpleType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTEGER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLOAT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOLEAN', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATETIME', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DURATION', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BINARY', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRUCT', index=9, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=972,
  serialized_end=1106,
)
_sym_db.RegisterEnumDescriptor(_SIMPLETYPE)

SimpleType = enum_type_wrapper.EnumTypeWrapper(_SIMPLETYPE)
NONE = 0
INTEGER = 1
FLOAT = 2
STRING = 3
BOOLEAN = 4
DATETIME = 5
DURATION = 6
BINARY = 7
ERROR = 8
STRUCT = 9


_SCHEMATYPE_SCHEMACOLUMN_SCHEMACOLUMNTYPE = _descriptor.EnumDescriptor(
  name='SchemaColumnType',
  full_name='flyteidl.core.SchemaType.SchemaColumn.SchemaColumnType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INTEGER', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLOAT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOLEAN', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATETIME', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DURATION', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=248,
  serialized_end=343,
)
_sym_db.RegisterEnumDescriptor(_SCHEMATYPE_SCHEMACOLUMN_SCHEMACOLUMNTYPE)

_BLOBTYPE_BLOBDIMENSIONALITY = _descriptor.EnumDescriptor(
  name='BlobDimensionality',
  full_name='flyteidl.core.BlobType.BlobDimensionality',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SINGLE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPART', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=442,
  serialized_end=489,
)
_sym_db.RegisterEnumDescriptor(_BLOBTYPE_BLOBDIMENSIONALITY)


_SCHEMATYPE_SCHEMACOLUMN = _descriptor.Descriptor(
  name='SchemaColumn',
  full_name='flyteidl.core.SchemaType.SchemaColumn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='flyteidl.core.SchemaType.SchemaColumn.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='flyteidl.core.SchemaType.SchemaColumn.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCHEMATYPE_SCHEMACOLUMN_SCHEMACOLUMNTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=343,
)

_SCHEMATYPE = _descriptor.Descriptor(
  name='SchemaType',
  full_name='flyteidl.core.SchemaType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='columns', full_name='flyteidl.core.SchemaType.columns', index=0,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SCHEMATYPE_SCHEMACOLUMN, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=343,
)


_BLOBTYPE = _descriptor.Descriptor(
  name='BlobType',
  full_name='flyteidl.core.BlobType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='format', full_name='flyteidl.core.BlobType.format', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dimensionality', full_name='flyteidl.core.BlobType.dimensionality', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BLOBTYPE_BLOBDIMENSIONALITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=346,
  serialized_end=489,
)


_ENUMTYPE = _descriptor.Descriptor(
  name='EnumType',
  full_name='flyteidl.core.EnumType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='flyteidl.core.EnumType.values', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=491,
  serialized_end=517,
)


_LITERALTYPE = _descriptor.Descriptor(
  name='LiteralType',
  full_name='flyteidl.core.LiteralType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='simple', full_name='flyteidl.core.LiteralType.simple', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schema', full_name='flyteidl.core.LiteralType.schema', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_type', full_name='flyteidl.core.LiteralType.collection_type', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='map_value_type', full_name='flyteidl.core.LiteralType.map_value_type', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob', full_name='flyteidl.core.LiteralType.blob', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enum_type', full_name='flyteidl.core.LiteralType.enum_type', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='flyteidl.core.LiteralType.metadata', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='flyteidl.core.LiteralType.type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=520,
  serialized_end=870,
)


_OUTPUTREFERENCE = _descriptor.Descriptor(
  name='OutputReference',
  full_name='flyteidl.core.OutputReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='flyteidl.core.OutputReference.node_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='var', full_name='flyteidl.core.OutputReference.var', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=872,
  serialized_end=919,
)


_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='flyteidl.core.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='failed_node_id', full_name='flyteidl.core.Error.failed_node_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='flyteidl.core.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=921,
  serialized_end=969,
)

_SCHEMATYPE_SCHEMACOLUMN.fields_by_name['type'].enum_type = _SCHEMATYPE_SCHEMACOLUMN_SCHEMACOLUMNTYPE
_SCHEMATYPE_SCHEMACOLUMN.containing_type = _SCHEMATYPE
_SCHEMATYPE_SCHEMACOLUMN_SCHEMACOLUMNTYPE.containing_type = _SCHEMATYPE_SCHEMACOLUMN
_SCHEMATYPE.fields_by_name['columns'].message_type = _SCHEMATYPE_SCHEMACOLUMN
_BLOBTYPE.fields_by_name['dimensionality'].enum_type = _BLOBTYPE_BLOBDIMENSIONALITY
_BLOBTYPE_BLOBDIMENSIONALITY.containing_type = _BLOBTYPE
_LITERALTYPE.fields_by_name['simple'].enum_type = _SIMPLETYPE
_LITERALTYPE.fields_by_name['schema'].message_type = _SCHEMATYPE
_LITERALTYPE.fields_by_name['collection_type'].message_type = _LITERALTYPE
_LITERALTYPE.fields_by_name['map_value_type'].message_type = _LITERALTYPE
_LITERALTYPE.fields_by_name['blob'].message_type = _BLOBTYPE
_LITERALTYPE.fields_by_name['enum_type'].message_type = _ENUMTYPE
_LITERALTYPE.fields_by_name['metadata'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_LITERALTYPE.oneofs_by_name['type'].fields.append(
  _LITERALTYPE.fields_by_name['simple'])
_LITERALTYPE.fields_by_name['simple'].containing_oneof = _LITERALTYPE.oneofs_by_name['type']
_LITERALTYPE.oneofs_by_name['type'].fields.append(
  _LITERALTYPE.fields_by_name['schema'])
_LITERALTYPE.fields_by_name['schema'].containing_oneof = _LITERALTYPE.oneofs_by_name['type']
_LITERALTYPE.oneofs_by_name['type'].fields.append(
  _LITERALTYPE.fields_by_name['collection_type'])
_LITERALTYPE.fields_by_name['collection_type'].containing_oneof = _LITERALTYPE.oneofs_by_name['type']
_LITERALTYPE.oneofs_by_name['type'].fields.append(
  _LITERALTYPE.fields_by_name['map_value_type'])
_LITERALTYPE.fields_by_name['map_value_type'].containing_oneof = _LITERALTYPE.oneofs_by_name['type']
_LITERALTYPE.oneofs_by_name['type'].fields.append(
  _LITERALTYPE.fields_by_name['blob'])
_LITERALTYPE.fields_by_name['blob'].containing_oneof = _LITERALTYPE.oneofs_by_name['type']
_LITERALTYPE.oneofs_by_name['type'].fields.append(
  _LITERALTYPE.fields_by_name['enum_type'])
_LITERALTYPE.fields_by_name['enum_type'].containing_oneof = _LITERALTYPE.oneofs_by_name['type']
DESCRIPTOR.message_types_by_name['SchemaType'] = _SCHEMATYPE
DESCRIPTOR.message_types_by_name['BlobType'] = _BLOBTYPE
DESCRIPTOR.message_types_by_name['EnumType'] = _ENUMTYPE
DESCRIPTOR.message_types_by_name['LiteralType'] = _LITERALTYPE
DESCRIPTOR.message_types_by_name['OutputReference'] = _OUTPUTREFERENCE
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.enum_types_by_name['SimpleType'] = _SIMPLETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SchemaType = _reflection.GeneratedProtocolMessageType('SchemaType', (_message.Message,), dict(

  SchemaColumn = _reflection.GeneratedProtocolMessageType('SchemaColumn', (_message.Message,), dict(
    DESCRIPTOR = _SCHEMATYPE_SCHEMACOLUMN,
    __module__ = 'flyteidl.core.types_pb2'
    # @@protoc_insertion_point(class_scope:flyteidl.core.SchemaType.SchemaColumn)
    ))
  ,
  DESCRIPTOR = _SCHEMATYPE,
  __module__ = 'flyteidl.core.types_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.SchemaType)
  ))
_sym_db.RegisterMessage(SchemaType)
_sym_db.RegisterMessage(SchemaType.SchemaColumn)

BlobType = _reflection.GeneratedProtocolMessageType('BlobType', (_message.Message,), dict(
  DESCRIPTOR = _BLOBTYPE,
  __module__ = 'flyteidl.core.types_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.BlobType)
  ))
_sym_db.RegisterMessage(BlobType)

EnumType = _reflection.GeneratedProtocolMessageType('EnumType', (_message.Message,), dict(
  DESCRIPTOR = _ENUMTYPE,
  __module__ = 'flyteidl.core.types_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.EnumType)
  ))
_sym_db.RegisterMessage(EnumType)

LiteralType = _reflection.GeneratedProtocolMessageType('LiteralType', (_message.Message,), dict(
  DESCRIPTOR = _LITERALTYPE,
  __module__ = 'flyteidl.core.types_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.LiteralType)
  ))
_sym_db.RegisterMessage(LiteralType)

OutputReference = _reflection.GeneratedProtocolMessageType('OutputReference', (_message.Message,), dict(
  DESCRIPTOR = _OUTPUTREFERENCE,
  __module__ = 'flyteidl.core.types_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.OutputReference)
  ))
_sym_db.RegisterMessage(OutputReference)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), dict(
  DESCRIPTOR = _ERROR,
  __module__ = 'flyteidl.core.types_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.Error)
  ))
_sym_db.RegisterMessage(Error)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/event/event.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import literals_pb2 as flyteidl_dot_core_dot_literals__pb2
from flyteidl.core import compiler_pb2 as flyteidl_dot_core_dot_compiler__pb2
from flyteidl.core import execution_pb2 as flyteidl_dot_core_dot_execution__pb2
from flyteidl.core import identifier_pb2 as flyteidl_dot_core_dot_identifier__pb2
from flyteidl.core import catalog_pb2 as flyteidl_dot_core_dot_catalog__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/event/event.proto',
  package='flyteidl.event',
  syntax='proto3',
  serialized_options=_b('Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/event'),
  serialized_pb=_b('\n\x1a\x66lyteidl/event/event.proto\x12\x0e\x66lyteidl.event\x1a\x1c\x66lyteidl/core/literals.proto\x1a\x1c\x66lyteidl/core/compiler.proto\x1a\x1d\x66lyteidl/core/execution.proto\x1a\x1e\x66lyteidl/core/identifier.proto\x1a\x1b\x66lyteidl/core/catalog.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xe0\x02\n\x16WorkflowExecutionEvent\x12@\n\x0c\x65xecution_id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\x12\x13\n\x0bproducer_id\x18\x02 \x01(\t\x12\x35\n\x05phase\x18\x03 \x01(\x0e\x32&.flyteidl.core.WorkflowExecution.Phase\x12/\n\x0boccurred_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\noutput_uri\x18\x05 \x01(\tH\x00\x12.\n\x05\x65rror\x18\x06 \x01(\x0b\x32\x1d.flyteidl.core.ExecutionErrorH\x00\x12\x30\n\x0boutput_data\x18\x07 \x01(\x0b\x32\x19.flyteidl.core.LiteralMapH\x00\x42\x0f\n\routput_result\"\xcc\x05\n\x12NodeExecutionEvent\x12\x32\n\x02id\x18\x01 \x01(\x0b\x32&.flyteidl.core.NodeExecutionIdentifier\x12\x13\n\x0bproducer_id\x18\x02 \x01(\t\x12\x31\n\x05phase\x18\x03 \x01(\x0e\x32\".flyteidl.core.NodeExecution.Phase\x12/\n\x0boccurred_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tinput_uri\x18\x05 \x01(\t\x12\x14\n\noutput_uri\x18\x06 \x01(\tH\x00\x12.\n\x05\x65rror\x18\x07 \x01(\x0b\x32\x1d.flyteidl.core.ExecutionErrorH\x00\x12\x30\n\x0boutput_data\x18\x0f \x01(\x0b\x32\x19.flyteidl.core.LiteralMapH\x00\x12\x46\n\x16workflow_node_metadata\x18\x08 \x01(\x0b\x32$.flyteidl.event.WorkflowNodeMetadataH\x01\x12>\n\x12task_node_metadata\x18\x0e \x01(\x0b\x32 .flyteidl.event.TaskNodeMetadataH\x01\x12I\n\x14parent_task_metadata\x18\t \x01(\x0b\x32+.flyteidl.event.ParentTaskExecutionMetadata\x12I\n\x14parent_node_metadata\x18\n \x01(\x0b\x32+.flyteidl.event.ParentNodeExecutionMetadata\x12\x13\n\x0bretry_group\x18\x0b \x01(\t\x12\x14\n\x0cspec_node_id\x18\x0c \x01(\t\x12\x11\n\tnode_name\x18\r \x01(\tB\x0f\n\routput_resultB\x11\n\x0ftarget_metadata\"X\n\x14WorkflowNodeMetadata\x12@\n\x0c\x65xecution_id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\"\xc7\x01\n\x10TaskNodeMetadata\x12\x37\n\x0c\x63\x61\x63he_status\x18\x01 \x01(\x0e\x32!.flyteidl.core.CatalogCacheStatus\x12\x33\n\x0b\x63\x61talog_key\x18\x02 \x01(\x0b\x32\x1e.flyteidl.core.CatalogMetadata\x12\x45\n\x10\x64ynamic_workflow\x18\x10 \x01(\x0b\x32+.flyteidl.event.DynamicWorkflowNodeMetadata\"\x87\x01\n\x1b\x44ynamicWorkflowNodeMetadata\x12%\n\x02id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.Identifier\x12\x41\n\x11\x63ompiled_workflow\x18\x02 \x01(\x0b\x32&.flyteidl.core.CompiledWorkflowClosure\"Q\n\x1bParentTaskExecutionMetadata\x12\x32\n\x02id\x18\x01 \x01(\x0b\x32&.flyteidl.core.TaskExecutionIdentifier\".\n\x1bParentNodeExecutionMetadata\x12\x0f\n\x07node_id\x18\x01 \x01(\t\"\xfd\x04\n\x12TaskExecutionEvent\x12*\n\x07task_id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.Identifier\x12H\n\x18parent_node_execution_id\x18\x02 \x01(\x0b\x32&.flyteidl.core.NodeExecutionIdentifier\x12\x15\n\rretry_attempt\x18\x03 \x01(\r\x12\x31\n\x05phase\x18\x04 \x01(\x0e\x32\".flyteidl.core.TaskExecution.Phase\x12\x13\n\x0bproducer_id\x18\x05 \x01(\t\x12$\n\x04logs\x18\x06 \x03(\x0b\x32\x16.flyteidl.core.TaskLog\x12/\n\x0boccurred_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tinput_uri\x18\x08 \x01(\t\x12\x14\n\noutput_uri\x18\t \x01(\tH\x00\x12.\n\x05\x65rror\x18\n \x01(\x0b\x32\x1d.flyteidl.core.ExecutionErrorH\x00\x12\x30\n\x0boutput_data\x18\x11 \x01(\x0b\x32\x19.flyteidl.core.LiteralMapH\x00\x12,\n\x0b\x63ustom_info\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rphase_version\x18\x0c \x01(\r\x12\x0e\n\x06reason\x18\r \x01(\t\x12\x11\n\ttask_type\x18\x0e \x01(\t\x12\x37\n\x08metadata\x18\x10 \x01(\x0b\x32%.flyteidl.event.TaskExecutionMetadataB\x0f\n\routput_result\"+\n\x14\x45xternalResourceInfo\x12\x13\n\x0b\x65xternal_id\x18\x01 \x01(\t\"?\n\x10ResourcePoolInfo\x12\x18\n\x10\x61llocation_token\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\"\xc8\x02\n\x15TaskExecutionMetadata\x12\x16\n\x0egenerated_name\x18\x01 \x01(\t\x12@\n\x12\x65xternal_resources\x18\x02 \x03(\x0b\x32$.flyteidl.event.ExternalResourceInfo\x12<\n\x12resource_pool_info\x18\x03 \x03(\x0b\x32 .flyteidl.event.ResourcePoolInfo\x12\x19\n\x11plugin_identifier\x18\x04 \x01(\t\x12K\n\x0einstance_class\x18\x10 \x01(\x0e\x32\x33.flyteidl.event.TaskExecutionMetadata.InstanceClass\"/\n\rInstanceClass\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x11\n\rINTERRUPTIBLE\x10\x01\x42\x37Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/eventb\x06proto3')
  ,
  dependencies=[flyteidl_dot_core_dot_literals__pb2.DESCRIPTOR,flyteidl_dot_core_dot_compiler__pb2.DESCRIPTOR,flyteidl_dot_core_dot_execution__pb2.DESCRIPTOR,flyteidl_dot_core_dot_identifier__pb2.DESCRIPTOR,flyteidl_dot_core_dot_catalog__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])



_TASKEXECUTIONMETADATA_INSTANCECLASS = _descriptor.EnumDescriptor(
  name='InstanceClass',
  full_name='flyteidl.event.TaskExecutionMetadata.InstanceClass',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERRUPTIBLE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2928,
  serialized_end=2975,
)
_sym_db.RegisterEnumDescriptor(_TASKEXECUTIONMETADATA_INSTANCECLASS)


_WORKFLOWEXECUTIONEVENT = _descriptor.Descriptor(
  name='WorkflowExecutionEvent',
  full_name='flyteidl.event.WorkflowExecutionEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='execution_id', full_name='flyteidl.event.WorkflowExecutionEvent.execution_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='producer_id', full_name='flyteidl.event.WorkflowExecutionEvent.producer_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phase', full_name='flyteidl.event.WorkflowExecutionEvent.phase', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='occurred_at', full_name='flyteidl.event.WorkflowExecutionEvent.occurred_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_uri', full_name='flyteidl.event.WorkflowExecutionEvent.output_uri', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='flyteidl.event.WorkflowExecutionEvent.error', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_data', full_name='flyteidl.event.WorkflowExecutionEvent.output_data', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='output_result', full_name='flyteidl.event.WorkflowExecutionEvent.output_result',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=262,
  serialized_end=614,
)


_NODEEXECUTIONEVENT = _descriptor.Descriptor(
  name='NodeExecutionEvent',
  full_name='flyteidl.event.NodeExecutionEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.event.NodeExecutionEvent.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='producer_id', full_name='flyteidl.event.NodeExecutionEvent.producer_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phase', full_name='flyteidl.event.NodeExecutionEvent.phase', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='occurred_at', full_name='flyteidl.event.NodeExecutionEvent.occurred_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_uri', full_name='flyteidl.event.NodeExecutionEvent.input_uri', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_uri', full_name='flyteidl.event.NodeExecutionEvent.output_uri', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='flyteidl.event.NodeExecutionEvent.error', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_data', full_name='flyteidl.event.NodeExecutionEvent.output_data', index=7,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workflow_node_metadata', full_name='flyteidl.event.NodeExecutionEvent.workflow_node_metadata', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='task_node_metadata', full_name='flyteidl.event.NodeExecutionEvent.task_node_metadata', index=9,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_task_metadata', full_name='flyteidl.event.NodeExecutionEvent.parent_task_metadata', index=10,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_node_metadata', full_name='flyteidl.event.NodeExecutionEvent.parent_node_metadata', index=11,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='retry_group', full_name='flyteidl.event.NodeExecutionEvent.retry_group', index=12,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec_node_id', full_name='flyteidl.event.NodeExecutionEvent.spec_node_id', index=13,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_name', full_name='flyteidl.event.NodeExecutionEvent.node_name', index=14,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='output_result', full_name='flyteidl.event.NodeExecutionEvent.output_result',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='target_metadata', full_name='flyteidl.event.NodeExecutionEvent.target_metadata',
      index=1, containing_type=None, fields=[]),
  ],
  serialized_start=617,
  serialized_end=1333,
)


_WORKFLOWNODEMETADATA = _descriptor.Descriptor(
  name='WorkflowNodeMetadata',
  full_name='flyteidl.event.WorkflowNodeMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='execution_id', full_name='flyteidl.event.WorkflowNodeMetadata.execution_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1335,
  serialized_end=1423,
)


_TASKNODEMETADATA = _descriptor.Descriptor(
  name='TaskNodeMetadata',
  full_name='flyteidl.event.TaskNodeMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cache_status', full_name='flyteidl.event.TaskNodeMetadata.cache_status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='catalog_key', full_name='flyteidl.event.TaskNodeMetadata.catalog_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dynamic_workflow', full_name='flyteidl.event.TaskNodeMetadata.dynamic_workflow', index=2,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1426,
  serialized_end=1625,
)


_DYNAMICWORKFLOWNODEMETADATA = _descriptor.Descriptor(
  name='DynamicWorkflowNodeMetadata',
  full_name='flyteidl.event.DynamicWorkflowNodeMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.event.DynamicWorkflowNodeMetadata.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compiled_workflow', full_name='flyteidl.event.DynamicWorkflowNodeMetadata.compiled_workflow', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1628,
  serialized_end=1763,
)


_PARENTTASKEXECUTIONMETADATA = _descriptor.Descriptor(
  name='ParentTaskExecutionMetadata',
  full_name='flyteidl.event.ParentTaskExecutionMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.event.ParentTaskExecutionMetadata.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1765,
  serialized_end=1846,
)


_PARENTNODEEXECUTIONMETADATA = _descriptor.Descriptor(
  name='ParentNodeExecutionMetadata',
  full_name='flyteidl.event.ParentNodeExecutionMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='flyteidl.event.ParentNodeExecutionMetadata.node_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1848,
  serialized_end=1894,
)


_TASKEXECUTIONEVENT = _descriptor.Descriptor(
  name='TaskExecutionEvent',
  full_name='flyteidl.event.TaskExecutionEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_id', full_name='flyteidl.event.TaskExecutionEvent.task_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_node_execution_id', full_name='flyteidl.event.TaskExecutionEvent.parent_node_execution_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='retry_attempt', full_name='flyteidl.event.TaskExecutionEvent.retry_attempt', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phase', full_name='flyteidl.event.TaskExecutionEvent.phase', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='producer_id', full_name='flyteidl.event.TaskExecutionEvent.producer_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logs', full_name='flyteidl.event.TaskExecutionEvent.logs', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='occurred_at', full_name='flyteidl.event.TaskExecutionEvent.occurred_at', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_uri', full_name='flyteidl.event.TaskExecutionEvent.input_uri', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_uri', full_name='flyteidl.event.TaskExecutionEvent.output_uri', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='flyteidl.event.TaskExecutionEvent.error', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_data', full_name='flyteidl.event.TaskExecutionEvent.output_data', index=10,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_info', full_name='flyteidl.event.TaskExecutionEvent.custom_info', index=11,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phase_version', full_name='flyteidl.event.TaskExecutionEvent.phase_version', index=12,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reason', full_name='flyteidl.event.TaskExecutionEvent.reason', index=13,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='task_type', full_name='flyteidl.event.TaskExecutionEvent.task_type', index=14,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='flyteidl.event.TaskExecutionEvent.metadata', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='output_result', full_name='flyteidl.event.TaskExecutionEvent.output_result',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1897,
  serialized_end=2534,
)


_EXTERNALRESOURCEINFO = _descriptor.Descriptor(
  name='ExternalResourceInfo',
  full_name='flyteidl.event.ExternalResourceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='external_id', full_name='flyteidl.event.ExternalResourceInfo.external_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2536,
  serialized_end=2579,
)


_RESOURCEPOOLINFO = _descriptor.Descriptor(
  name='ResourcePoolInfo',
  full_name='flyteidl.event.ResourcePoolInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='allocation_token', full_name='flyteidl.event.ResourcePoolInfo.allocation_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='flyteidl.event.ResourcePoolInfo.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2581,
  serialized_end=2644,
)


_TASKEXECUTIONMETADATA = _descriptor.Descriptor(
  name='TaskExecutionMetadata',
  full_name='flyteidl.event.TaskExecutionMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='generated_name', full_name='flyteidl.event.TaskExecutionMetadata.generated_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='external_resources', full_name='flyteidl.event.TaskExecutionMetadata.external_resources', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_pool_info', full_name='flyteidl.event.TaskExecutionMetadata.resource_pool_info', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plugin_identifier', full_name='flyteidl.event.TaskExecutionMetadata.plugin_identifier', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instance_class', full_name='flyteidl.event.TaskExecutionMetadata.instance_class', index=4,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TASKEXECUTIONMETADATA_INSTANCECLASS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2647,
  serialized_end=2975,
)

_WORKFLOWEXECUTIONEVENT.fields_by_name['execution_id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_WORKFLOWEXECUTIONEVENT.fields_by_name['phase'].enum_type = flyteidl_dot_core_dot_execution__pb2._WORKFLOWEXECUTION_PHASE
_WORKFLOWEXECUTIONEVENT.fields_by_name['occurred_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_WORKFLOWEXECUTIONEVENT.fields_by_name['error'].message_type = flyteidl_dot_core_dot_execution__pb2._EXECUTIONERROR
_WORKFLOWEXECUTIONEVENT.fields_by_name['output_data'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
_WORKFLOWEXECUTIONEVENT.oneofs_by_name['output_result'].fields.append(
  _WORKFLOWEXECUTIONEVENT.fields_by_name['output_uri'])
_WORKFLOWEXECUTIONEVENT.fields_by_name['output_uri'].containing_oneof = _WORKFLOWEXECUTIONEVENT.oneofs_by_name['output_result']
_WORKFLOWEXECUTIONEVENT.oneofs_by_name['output_result'].fields.append(
  _WORKFLOWEXECUTIONEVENT.fields_by_name['error'])
_WORKFLOWEXECUTIONEVENT.fields_by_name['error'].containing_oneof = _WORKFLOWEXECUTIONEVENT.oneofs_by_name['output_result']
_WORKFLOWEXECUTIONEVENT.oneofs_by_name['output_result'].fields.append(
  _WORKFLOWEXECUTIONEVENT.fields_by_name['output_data'])
_WORKFLOWEXECUTIONEVENT.fields_by_name['output_data'].containing_oneof = _WORKFLOWEXECUTIONEVENT.oneofs_by_name['output_result']
_NODEEXECUTIONEVENT.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._NODEEXECUTIONIDENTIFIER
_NODEEXECUTIONEVENT.fields_by_name['phase'].enum_type = flyteidl_dot_core_dot_execution__pb2._NODEEXECUTION_PHASE
_NODEEXECUTIONEVENT.fields_by_name['occurred_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_NODEEXECUTIONEVENT.fields_by_name['error'].message_type = flyteidl_dot_core_dot_execution__pb2._EXECUTIONERROR
_NODEEXECUTIONEVENT.fields_by_name['output_data'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
_NODEEXECUTIONEVENT.fields_by_name['workflow_node_metadata'].message_type = _WORKFLOWNODEMETADATA
_NODEEXECUTIONEVENT.fields_by_name['task_node_metadata'].message_type = _TASKNODEMETADATA
_NODEEXECUTIONEVENT.fields_by_name['parent_task_metadata'].message_type = _PARENTTASKEXECUTIONMETADATA
_NODEEXECUTIONEVENT.fields_by_name['parent_node_metadata'].message_type = _PARENTNODEEXECUTIONMETADATA
_NODEEXECUTIONEVENT.oneofs_by_name['output_result'].fields.append(
  _NODEEXECUTIONEVENT.fields_by_name['output_uri'])
_NODEEXECUTIONEVENT.fields_by_name['output_uri'].containing_oneof = _NODEEXECUTIONEVENT.oneofs_by_name['output_result']
_NODEEXECUTIONEVENT.oneofs_by_name['output_result'].fields.append(
  _NODEEXECUTIONEVENT.fields_by_name['error'])
_NODEEXECUTIONEVENT.fields_by_name['error'].containing_oneof = _NODEEXECUTIONEVENT.oneofs_by_name['output_result']
_NODEEXECUTIONEVENT.oneofs_by_name['output_result'].fields.append(
  _NODEEXECUTIONEVENT.fields_by_name['output_data'])
_NODEEXECUTIONEVENT.fields_by_name['output_data'].containing_oneof = _NODEEXECUTIONEVENT.oneofs_by_name['output_result']
_NODEEXECUTIONEVENT.oneofs_by_name['target_metadata'].fields.append(
  _NODEEXECUTIONEVENT.fields_by_name['workflow_node_metadata'])
_NODEEXECUTIONEVENT.fields_by_name['workflow_node_metadata'].containing_oneof = _NODEEXECUTIONEVENT.oneofs_by_name['target_metadata']
_NODEEXECUTIONEVENT.oneofs_by_name['target_metadata'].fields.append(
  _NODEEXECUTIONEVENT.fields_by_name['task_node_metadata'])
_NODEEXECUTIONEVENT.fields_by_name['task_node_metadata'].containing_oneof = _NODEEXECUTIONEVENT.oneofs_by_name['target_metadata']
_WORKFLOWNODEMETADATA.fields_by_name['execution_id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_TASKNODEMETADATA.fields_by_name['cache_status'].enum_type = flyteidl_dot_core_dot_catalog__pb2._CATALOGCACHESTATUS
_TASKNODEMETADATA.fields_by_name['catalog_key'].message_type = flyteidl_dot_core_dot_catalog__pb2._CATALOGMETADATA
_TASKNODEMETADATA.fields_by_name['dynamic_workflow'].message_type = _DYNAMICWORKFLOWNODEMETADATA
_DYNAMICWORKFLOWNODEMETADATA.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._IDENTIFIER
_DYNAMICWORKFLOWNODEMETADATA.fields_by_name['compiled_workflow'].message_type = flyteidl_dot_core_dot_compiler__pb2._COMPILEDWORKFLOWCLOSURE
_PARENTTASKEXECUTIONMETADATA.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._TASKEXECUTIONIDENTIFIER
_TASKEXECUTIONEVENT.fields_by_name['task_id'].message_type = flyteidl_dot_core_dot_identifier__pb2._IDENTIFIER
_TASKEXECUTIONEVENT.fields_by_name['parent_node_execution_id'].message_type = flyteidl_dot_core_dot_identifier__pb2._NODEEXECUTIONIDENTIFIER
_TASKEXECUTIONEVENT.fields_by_name['phase'].enum_type = flyteidl_dot_core_dot_execution__pb2._TASKEXECUTION_PHASE
_TASKEXECUTIONEVENT.fields_by_name['logs'].message_type = flyteidl_dot_core_dot_execution__pb2._TASKLOG
_TASKEXECUTIONEVENT.fields_by_name['occurred_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TASKEXECUTIONEVENT.fields_by_name['error'].message_type = flyteidl_dot_core_dot_execution__pb2._EXECUTIONERROR
_TASKEXECUTIONEVENT.fields_by_name['output_data'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
_TASKEXECUTIONEVENT.fields_by_name['custom_info'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_TASKEXECUTIONEVENT.fields_by_name['metadata'].message_type = _TASKEXECUTIONMETADATA
_TASKEXECUTIONEVENT.oneofs_by_name['output_result'].fields.append(
  _TASKEXECUTIONEVENT.fields_by_name['output_uri'])
_TASKEXECUTIONEVENT.fields_by_name['output_uri'].containing_oneof = _TASKEXECUTIONEVENT.oneofs_by_name['output_result']
_TASKEXECUTIONEVENT.oneofs_by_name['output_result'].fields.append(
  _TASKEXECUTIONEVENT.fields_by_name['error'])
_TASKEXECUTIONEVENT.fields_by_name['error'].containing_oneof = _TASKEXECUTIONEVENT.oneofs_by_name['output_result']
_TASKEXECUTIONEVENT.oneofs_by_name['output_result'].fields.append(
  _TASKEXECUTIONEVENT.fields_by_name['output_data'])
_TASKEXECUTIONEVENT.fields_by_name['output_data'].containing_oneof = _TASKEXECUTIONEVENT.oneofs_by_name['output_result']
_TASKEXECUTIONMETADATA.fields_by_name['external_resources'].message_type = _EXTERNALRESOURCEINFO
_TASKEXECUTIONMETADATA.fields_by_name['resource_pool_info'].message_type = _RESOURCEPOOLINFO
_TASKEXECUTIONMETADATA.fields_by_name['instance_class'].enum_type = _TASKEXECUTIONMETADATA_INSTANCECLASS
_TASKEXECUTIONMETADATA_INSTANCECLASS.containing_type = _TASKEXECUTIONMETADATA
DESCRIPTOR.message_types_by_name['WorkflowExecutionEvent'] = _WORKFLOWEXECUTIONEVENT
DESCRIPTOR.message_types_by_name['NodeExecutionEvent'] = _NODEEXECUTIONEVENT
DESCRIPTOR.message_types_by_name['WorkflowNodeMetadata'] = _WORKFLOWNODEMETADATA
DESCRIPTOR.message_types_by_name['TaskNodeMetadata'] = _TASKNODEMETADATA
DESCRIPTOR.message_types_by_name['DynamicWorkflowNodeMetadata'] = _DYNAMICWORKFLOWNODEMETADATA
DESCRIPTOR.message_types_by_name['ParentTaskExecutionMetadata'] = _PARENTTASKEXECUTIONMETADATA
DESCRIPTOR.message_types_by_name['ParentNodeExecutionMetadata'] = _PARENTNODEEXECUTIONMETADATA
DESCRIPTOR.message_types_by_name['TaskExecutionEvent'] = _TASKEXECUTIONEVENT
DESCRIPTOR.message_types_by_name['ExternalResourceInfo'] = _EXTERNALRESOURCEINFO
DESCRIPTOR.message_types_by_name['ResourcePoolInfo'] = _RESOURCEPOOLINFO
DESCRIPTOR.message_types_by_name['TaskExecutionMetadata'] = _TASKEXECUTIONMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WorkflowExecutionEvent = _reflection.GeneratedProtocolMessageType('WorkflowExecutionEvent', (_message.Message,), dict(
  DESCRIPTOR = _WORKFLOWEXECUTIONEVENT,
  __module__ = 'flyteidl.event.event_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.event.WorkflowExecutionEvent)
  ))
_sym_db.RegisterMessage(WorkflowExecutionEvent)

NodeExecutionEvent = _reflection.GeneratedProtocolMessageType('NodeExecutionEvent', (_message.Message,), dict(
  DESCRIPTOR = _NODEEXECUTIONEVENT,
  __module__ = 'flyteidl.event.event_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.event.NodeExecutionEvent)
  ))
_sym_db.RegisterMessage(NodeExecutionEvent)

WorkflowNodeMetadata = _reflection.GeneratedProtocolMessageType('WorkflowNodeMetadata', (_message.Message,), dict(
  DESCRIPTOR = _WORKFLOWNODEMETADATA,
  __module__ = 'flyteidl.event.event_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.event.WorkflowNodeMetadata)
  ))
_sym_db.RegisterMessage(WorkflowNodeMetadata)

TaskNodeMetadata = _reflection.GeneratedProtocolMessageType('TaskNodeMetadata', (_message.Message,), dict(
  DESCRIPTOR = _TASKNODEMETADATA,
  __module__ = 'flyteidl.event.event_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.event.TaskNodeMetadata)
  ))
_sym_db.RegisterMessage(TaskNodeMetadata)

DynamicWorkflowNodeMetadata = _reflection.GeneratedProtocolMessageType('DynamicWorkflowNodeMetadata', (_message.Message,), dict(
  DESCRIPTOR = _DYNAMICWORKFLOWNODEMETADATA,
  __module__ = 'flyteidl.event.event_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.event.DynamicWorkflowNodeMetadata)
  ))
_sym_db.RegisterMessage(DynamicWorkflowNodeMetadata)

ParentTaskExecutionMetadata = _reflection.GeneratedProtocolMessageType('ParentTaskExecutionMetadata', (_message.Message,), dict(
  DESCRIPTOR = _PARENTTASKEXECUTIONMETADATA,
  __module__ = 'flyteidl.event.event_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.event.ParentTaskExecutionMetadata)
  ))
_sym_db.RegisterMessage(ParentTaskExecutionMetadata)

ParentNodeExecutionMetadata = _reflection.GeneratedProtocolMessageType('ParentNodeExecutionMetadata', (_message.Message,), dict(
  DESCRIPTOR = _PARENTNODEEXECUTIONMETADATA,
  __module__ = 'flyteidl.event.event_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.event.ParentNodeExecutionMetadata)
  ))
_sym_db.RegisterMessage(ParentNodeExecutionMetadata)

TaskExecutionEvent = _reflection.GeneratedProtocolMessageType('TaskExecutionEvent', (_message.Message,), dict(
  DESCRIPTOR = _TASKEXECUTIONEVENT,
  __module__ = 'flyteidl.event.event_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.event.TaskExecutionEvent)
  ))
_sym_db.RegisterMessage(TaskExecutionEvent)

ExternalResourceInfo = _reflection.GeneratedProtocolMessageType('ExternalResourceInfo', (_message.Message,), dict(
  DESCRIPTOR = _EXTERNALRESOURCEINFO,
  __module__ = 'flyteidl.event.event_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.event.ExternalResourceInfo)
  ))
_sym_db.RegisterMessage(ExternalResourceInfo)

ResourcePoolInfo = _reflection.GeneratedProtocolMessageType('ResourcePoolInfo', (_message.Message,), dict(
  DESCRIPTOR = _RESOURCEPOOLINFO,
  __module__ = 'flyteidl.event.event_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.event.ResourcePoolInfo)
  ))
_sym_db.RegisterMessage(ResourcePoolInfo)

TaskExecutionMetadata = _reflection.GeneratedProtocolMessageType('TaskExecutionMetadata', (_message.Message,), dict(
  DESCRIPTOR = _TASKEXECUTIONMETADATA,
  __module__ = 'flyteidl.event.event_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.event.TaskExecutionMetadata)
  ))
_sym_db.RegisterMessage(TaskExecutionMetadata)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
